@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.69 2003/12/29 09:42:42 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.72 2003/12/30 19:56:40 fuyu Exp $
  */
 
 #include "config.h"
@@ -131,24 +131,6 @@ static guint message_id;
 guint thread_netstat_id;
 
 
-#if 0	/* Ϥפäݤ */
-static pthread_mutex_t thread_info_lock;
-#define THREAD_INFO_LOCK				\
-  if (pthread_mutex_lock(&thread_info_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't lock a mutex.\n");	\
-      abort();						\
-    }
-
-#define THREAD_INFO_UNLOCK				\
-  if (pthread_mutex_unlock(&thread_info_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't unlock a mutex.\n");	\
-      abort();						\
-    }
-#endif
-
-
 #define BBS_THREAD_UI_LOCK				\
   if (pthread_mutex_lock(&bbs_thread_ui_lock) != 0)	\
     {							\
@@ -254,14 +236,6 @@ static GQuark popup_parent_context_id;
 void
 prepare_thread_ui_initialization(OchushaApplication *application)
 {
-#ifdef THREAD_INFO_LOCK
-  if (pthread_mutex_init(&thread_info_lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-#endif
-
   if (pthread_mutex_init(&bbs_thread_ui_lock, NULL) != 0)
     {
       fprintf(stderr, "Couldn't init a mutex.\n");
@@ -319,7 +293,7 @@ font_selection_dialog_response_cb(GtkWidget *dialog, gint response_id,
       break;
 
     case GTK_RESPONSE_CANCEL:
-      reset_thread_view_font(font_name);
+      reset_thread_view_font();
       break;
     }
 
@@ -393,7 +367,8 @@ set_thread_view_font(const char *font_name)
 }
 
 
-void reset_thread_view_font()
+void
+reset_thread_view_font(void)
 {
   g_return_if_fail(thread_title_tag != NULL);
   g_return_if_fail(response_header_tag != NULL);
@@ -536,7 +511,7 @@ initialize_thread_ui(OchushaApplication *application)
 	NULL,
 	NULL,
 	0,
-	"<Separator>"
+	(char *)"<Separator>"
       },
       {
 	_("/_Save Link As..."),				/* menu path */
@@ -619,7 +594,7 @@ initialize_thread_ui(OchushaApplication *application)
     tag_table = g_hash_table_new(g_str_hash, g_str_equal);
 
     /* TODO: äȡ */
-    g_hash_table_insert(tag_table, "b", bold_tag);
+    g_hash_table_insert(tag_table, (char *)"b", bold_tag);
   }
 
   if (application->thread_view_font_name != NULL
@@ -677,7 +652,6 @@ bbs_thread_info_free(BBSThreadGUIInfo *info)
 BBSThreadGUIInfo *
 ensure_bbs_thread_info(OchushaBBSThread *thread)
 {
-#ifndef THREAD_INFO_LOCK
   BBSThreadGUIInfo *info = g_object_get_qdata(G_OBJECT(thread),
 					      bbs_thread_gui_info_id);
   if (info == NULL)
@@ -686,24 +660,6 @@ ensure_bbs_thread_info(OchushaBBSThread *thread)
       g_object_set_qdata_full(G_OBJECT(thread), bbs_thread_gui_info_id,
 			      info, (GDestroyNotify)bbs_thread_info_free);
     }
-#else
-  BBSThreadGUIInfo *info = g_object_get_qdata(G_OBJECT(thread),
-					      bbs_thread_gui_info_id);
-  if (info != NULL)
-    return info;
-
-  THREAD_INFO_LOCK
-  {
-    info = g_object_get_qdata(G_OBJECT(thread), bbs_thread_gui_info_id);
-    if (info == NULL)
-      {
-	info = G_NEW0(BBSThreadGUIInfo, 1);
-	g_object_set_qdata_full(G_OBJECT(thread), bbs_thread_gui_info_id,
-				info, (GDestroyNotify)bbs_thread_info_free);
-      }
-  }
-  THREAD_INFO_UNLOCK;
-#endif
 
   return info;
 }
@@ -751,6 +707,17 @@ typedef struct _BBSThreadJobArgs
 } BBSThreadJobArgs;
 
 
+static void
+mark_deleted_cb(GtkTextBuffer *buffer, GtkTextMark *mark,
+		BBSThreadGUIInfo *info)
+{
+  if (info->last_read == mark)
+    info->last_read = NULL;
+  if (info->next_mark == mark)
+    info->next_mark = NULL;
+}
+
+
 GtkWidget *
 open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 		IconLabel *tab_label)
@@ -825,6 +792,9 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
     g_signal_connect(G_OBJECT(thread_view), "scroll_view",
 		     G_CALLBACK(scroll_view_cb), application);
 
+    g_signal_connect(G_OBJECT(job_args->view->text_buffer), "mark_deleted",
+		     G_CALLBACK(mark_deleted_cb), info);
+
 #if DEBUG_ASYNC_BUFFER_MOST
     fprintf(stderr, "open_bbs_thread: ref AsyncBuffer(%p)\n", buffer);
     fprintf(stderr, "* before ref: buffer->ref_count=%d\n",
@@ -1252,7 +1222,9 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
 				     event->button,
 				     gtk_get_current_event_time());
   else
-    ochusha_open_url(application, link, event->button == 2, FALSE);
+    ochusha_open_url(application, link,
+		     application->default_open_in_tab
+		     ? event->button == 1 : event->button == 2, FALSE);
 
   return TRUE;
 }
@@ -1862,6 +1834,8 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
       /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
       info->last_read = bbs_thread_view_create_mark(view);
     }
+  else
+    info->last_read = NULL;
 
   bbs_thread_view_push_tag(view, context->thread_title_tag);
 
