@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.32 2003/12/29 08:46:00 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.34 2003/12/30 19:56:40 fuyu Exp $
  */
 
 #include "config.h"
@@ -85,7 +85,7 @@ static gboolean button_press_event_cb(GtkTextView *text_view,
 static gboolean button_release_event_cb(GtkTextView *text_view,
 					GdkEventButton *event,
 					BBSThreadView *bbs_thread_view);
-static void bbs_thread_view_scroll_to(BBSThreadView *view, gint to_where);
+static void bbs_thread_view_scroll_to(BBSThreadView *view, int to_where);
 
 
 GType
@@ -139,7 +139,7 @@ enum {
 
 
 static GtkTextViewClass *parent_class = NULL;
-static gint bbs_thread_view_signals[LAST_SIGNAL] =
+static int bbs_thread_view_signals[LAST_SIGNAL] =
   { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 static GtkTextTagTable *default_tag_table;
 
@@ -606,8 +606,8 @@ text_view_get_iter_at_link_tag_from_event(GtkTextView *text_view,
 					  GtkTextIter *iter,
 					  GdkEventAny *event)
 {
-  gint buf_x;
-  gint buf_y;
+  int buf_x;
+  int buf_y;
 
   switch (event->type)
     {
@@ -734,7 +734,7 @@ motion_notify_event_cb(GtkTextView *text_view, GdkEventMotion *event,
   if (text_view_get_iter_at_link_tag_from_event(text_view, &iter,
 						(GdkEventAny *)event))
     {
-      gint start_offset = gtk_text_iter_get_offset(&iter);
+      int start_offset = gtk_text_iter_get_offset(&iter);
       if (start_offset == bbs_thread_view->last_offset)
 	{
 	  ENTER_MAIN_EVENT_LOOP();
@@ -831,7 +831,7 @@ button_press_event_cb(GtkTextView *text_view, GdkEventButton *event,
 						(GdkEventAny *)event))
     {
       gboolean handled;
-      gint start_offset = gtk_text_iter_get_offset(&iter);
+      int start_offset = gtk_text_iter_get_offset(&iter);
       gchar *link = (bbs_thread_view->link_table != NULL)
 	? (gchar *)g_hash_table_lookup(bbs_thread_view->link_table,
 				       (gconstpointer)start_offset)
@@ -868,7 +868,7 @@ button_release_event_cb(GtkTextView *text_view, GdkEventButton *event,
 						(GdkEventAny *)event))
     {
       gboolean handled;
-      gint start_offset = gtk_text_iter_get_offset(&iter);
+      int start_offset = gtk_text_iter_get_offset(&iter);
       gchar *link = (bbs_thread_view->link_table != NULL)
 	? (gchar *)g_hash_table_lookup(bbs_thread_view->link_table,
 				       (gconstpointer)start_offset)
@@ -942,13 +942,11 @@ bbs_thread_view_clear(BBSThreadView *view)
 }
 
 
-gint
+int
 bbs_thread_view_get_current_offset(BBSThreadView *view)
 {
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view), 0);
-
-  if (view->text_buffer == NULL)
-    return 0;
+  g_return_val_if_fail(view->text_buffer != NULL, 0);
 
   return gtk_text_iter_get_offset(&view->iter);
 }
@@ -960,9 +958,7 @@ bbs_thread_view_create_mark(BBSThreadView *view)
   GtkTextMark *mark;
 
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view), NULL);
-
-  if (view->text_buffer == NULL)
-    return NULL;
+  g_return_val_if_fail(view->text_buffer != NULL, NULL);
 
   mark = gtk_text_buffer_create_mark(view->text_buffer, NULL, &view->iter,
 				     TRUE); 
@@ -1015,7 +1011,7 @@ bbs_thread_view_append_text(BBSThreadView *view, const gchar *text, int len)
 {
   GtkTextIter start;
   ApplyTagArgs args;
-  gint start_offset;
+  int start_offset;
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && text != NULL);
 
@@ -1066,7 +1062,7 @@ bbs_thread_view_append_text_as_link(BBSThreadView *view,
 				    const gchar *link)
 {
   GtkTextIter start;
-  gint start_offset;
+  int start_offset;
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && text != NULL);
 
@@ -1093,7 +1089,7 @@ bbs_thread_view_append_text_as_sage(BBSThreadView *view,
 				    const gchar *link)
 {
   GtkTextIter start;
-  gint start_offset;
+  int start_offset;
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && text != NULL);
 
@@ -1141,22 +1137,22 @@ bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget)
 
 typedef struct _AdjustOffsetArgs
 {
-  gint offset;
+  int offset;
   GHashTable *hash_table;
   GHashTable *new_hash_table;
 } AdjustOffsetArgs;
 
 
-void
-increment_values(gpointer key, gint value, AdjustOffsetArgs *args)
+static void
+increment_values(gpointer key, int value, AdjustOffsetArgs *args)
 {
   if (value >= args->offset)
-    g_hash_table_replace(args->hash_table, key, (gpointer)value + 1);
+    g_hash_table_replace(args->hash_table, key, (gpointer)(value + 1));
 }
 
 
-gboolean
-update_link_table_increment(gint offset, char *url, AdjustOffsetArgs *args)
+static gboolean
+update_link_table_increment(int offset, char *url, AdjustOffsetArgs *args)
 {
   if (offset >= args->offset)
     g_hash_table_insert(args->new_hash_table, (gpointer)(offset + 1), url);
@@ -1169,12 +1165,12 @@ update_link_table_increment(gint offset, char *url, AdjustOffsetArgs *args)
 
 void
 bbs_thread_view_insert_widget_at_offset(BBSThreadView *view, GtkWidget *widget,
-					gint offset)
+					int offset)
 {
   GtkWidget *vbox;
   GtkWidget *hbox;
   GtkTextChildAnchor *anchor;
-  gint anchor_offset;
+  int anchor_offset;
   GtkTextIter iter;
   AdjustOffsetArgs args;
 
@@ -1215,16 +1211,16 @@ bbs_thread_view_insert_widget_at_offset(BBSThreadView *view, GtkWidget *widget,
 }
 
 
-void
-decrement_values(gpointer key, gint value, AdjustOffsetArgs *args)
+static void
+decrement_values(gpointer key, int value, AdjustOffsetArgs *args)
 {
   if (value >= args->offset)
-    g_hash_table_replace(args->hash_table, key, (gpointer)value - 1);
+    g_hash_table_replace(args->hash_table, key, (gpointer)(value - 1));
 }
 
 
-gboolean
-update_link_table_decrement(gint offset, char *url, AdjustOffsetArgs *args)
+static gboolean
+update_link_table_decrement(int offset, char *url, AdjustOffsetArgs *args)
 {
   if (offset >= args->offset)
     g_hash_table_insert(args->new_hash_table, (gpointer)(offset - 1), url);
@@ -1240,7 +1236,7 @@ bbs_thread_view_remove_widget(BBSThreadView *view, GtkWidget *widget)
 {
   GtkTextIter start;
   GtkTextIter end;
-  gint anchor_offset;
+  int anchor_offset;
   AdjustOffsetArgs args;
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
@@ -1350,7 +1346,7 @@ bbs_thread_view_pop_tags(BBSThreadView *view, GtkTextTag *tag)
 
 
 static void
-bbs_thread_view_scroll_to(BBSThreadView *view, gint to_where)
+bbs_thread_view_scroll_to(BBSThreadView *view, int to_where)
 {
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
@@ -1403,11 +1399,11 @@ bbs_thread_view_scroll_to_end(BBSThreadView *view)
 }
 
 
-gint
-bbs_thread_view_scroll_to_offset(BBSThreadView *view, gint offset)
+int
+bbs_thread_view_scroll_to_offset(BBSThreadView *view, int offset)
 {
   GtkTextIter iter;
-  gint previous_offset;
+  int previous_offset;
   gboolean result;
 
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_buffer != NULL,
@@ -1450,7 +1446,7 @@ bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark)
 
 
 GtkTextMark *
-bbs_thread_view_create_mark_at_offset(BBSThreadView *view, gint offset)
+bbs_thread_view_create_mark_at_offset(BBSThreadView *view, int offset)
 {
   GtkTextIter iter;
   GtkTextMark *mark;
@@ -1465,7 +1461,7 @@ bbs_thread_view_create_mark_at_offset(BBSThreadView *view, gint offset)
 
 
 void
-bbs_thread_view_place_cursor_at_offset(BBSThreadView *view, gint offset)
+bbs_thread_view_place_cursor_at_offset(BBSThreadView *view, int offset)
 {
   GtkTextIter iter;
 
@@ -1479,7 +1475,7 @@ bbs_thread_view_place_cursor_at_offset(BBSThreadView *view, gint offset)
 /* Ϣ */
 static void
 bbs_thread_view_scroll_to_offsets(BBSThreadView *view,
-				  gint start_offset, gint end_offset)
+				  int start_offset, int end_offset)
 {
   /* ޥåʬ򤷡ʬɽ褦˥ */
   GtkTextIter iter;
@@ -1501,8 +1497,8 @@ static gboolean
 bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 					 GtkTextIter *start_iter,
 					 GtkTextIter *end_iter,
-					 gint *match_start_offset_p,
-					 gint *match_end_offset_p)
+					 int *match_start_offset_p,
+					 int *match_end_offset_p)
 {
   gboolean result = FALSE;
   gchar *text;
@@ -1542,7 +1538,7 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 
       if (regexec(&view->regexp, text, 1, view->regexp_match, 0) == 0)
 	{
-	  gint offset = gtk_text_iter_get_offset(start_iter);
+	  int offset = gtk_text_iter_get_offset(start_iter);
 	  *match_start_offset_p
 	    = g_utf8_strlen(text, view->regexp_match[0].rm_so) + offset;
 	  *match_end_offset_p
@@ -1558,7 +1554,7 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
       gchar *match_start = strstr(text, view->search_key);
       if (match_start != NULL)
 	{
-	  gint offset = gtk_text_iter_get_offset(start_iter);
+	  int offset = gtk_text_iter_get_offset(start_iter);
 	  *match_start_offset_p
 	    = g_utf8_strlen(text, match_start - text) + offset;
 	  *match_end_offset_p
@@ -1578,8 +1574,8 @@ static gboolean
 bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 					  GtkTextIter *start_iter,
 					  GtkTextIter *end_iter,
-					  gint *match_start_offset_p,
-					  gint *match_end_offset_p)
+					  int *match_start_offset_p,
+					  int *match_end_offset_p)
 {
   gboolean result = FALSE;
   gchar *text;
@@ -1622,7 +1618,7 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 
       if (found)
 	{
-	  gint offset = gtk_text_iter_get_offset(start_iter);
+	  int offset = gtk_text_iter_get_offset(start_iter);
 	  *match_start_offset_p
 	    = g_utf8_strlen(text, last_start_pos - text) + offset;
 	  *match_end_offset_p
@@ -1636,7 +1632,7 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
       gchar *match_start = g_strrstr(text, view->search_key);
       if (match_start != NULL)
 	{
-	  gint offset = gtk_text_iter_get_offset(start_iter);
+	  int offset = gtk_text_iter_get_offset(start_iter);
 	  *match_start_offset_p
 	    = g_utf8_strlen(text, match_start - text) + offset;
 	  *match_end_offset_p
@@ -1658,8 +1654,8 @@ bbs_thread_view_do_search_forward(BBSThreadView *view,
 {
   GtkTextIter start;
   GtkTextIter end;
-  gint start_offset = 0;
-  gint end_offset = 0;
+  int start_offset = 0;
+  int end_offset = 0;
 
   if (view->use_regexp)
     {
@@ -1705,8 +1701,8 @@ bbs_thread_view_do_search_backward(BBSThreadView *view,
 {
   GtkTextIter start;
   GtkTextIter end;
-  gint start_offset = 0;
-  gint end_offset = 0;
+  int start_offset = 0;
+  int end_offset = 0;
 
   if (view->use_regexp)
     {
