@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.16 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.18 2003/12/18 15:56:34 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -88,6 +88,8 @@ struct _BBSThreadView
   OchushaBBSThread *thread;
   GHashTable *link_table;	/* offset=>linkʥơ֥ */
 
+  GHashTable *child_table;	/* child=>anchoroffsetפʥơ֥ */
+
 
   /* طǻȤ */
   gint last_match_offset;
@@ -136,8 +138,7 @@ struct _BBSThreadViewClass
 			    GdkEventCrossing *event);
 
   void (*scroll_to)(BBSThreadView *bbs_thread_view, gint to_where);
-  void (*move_cursor)(BBSThreadView *bbs_thread_view, GtkMovementStep step,
-		      gint count, gboolean extend_selection);
+  void (*scroll_view)(BBSThreadView *bbs_thread_view, GtkScrollType scroll);
   void (*interactive_search)(BBSThreadView *bbs_thread_view,
 			     BBSThreadViewSearchAction action);
   void (*write_response)(BBSThreadView *bbs_thread_view);
@@ -167,6 +168,10 @@ void bbs_thread_view_append_text_as_sage(BBSThreadView *view,
 					 const gchar *text, int len,
 					 const gchar *link);
 void bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget);
+void bbs_thread_view_insert_widget_at_offset(BBSThreadView *view,
+					     GtkWidget *widget,
+					     gint offset);
+void bbs_thread_view_remove_widget(BBSThreadView *view, GtkWidget *widget);
 
 GtkTextTag *bbs_thread_view_get_tag_by_name(BBSThreadView *view,
 					    const gchar *name);
