@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.48 2003/12/29 08:47:44 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.51 2003/12/30 20:48:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -148,24 +148,6 @@ static GSList *board_list;
 
 static pthread_mutex_t board_list_lock;
 
-#if 0	/* Ϥפäݤ*/
-static pthread_mutex_t category_info_lock;
-#define CATEGORY_INFO_LOCK				\
-  if (pthread_mutex_lock(&category_info_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't lock a mutex.\n");	\
-      abort();						\
-    }
-
-#define CATEGORY_INFO_UNLOCK				\
-  if (pthread_mutex_unlock(&category_info_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't unlock a mutex.\n");	\
-      abort();						\
-    }
-#endif
-
-
 #define BOARD_LIST_LOCK					\
   if (pthread_mutex_lock(&board_list_lock) != 0)	\
     {							\
@@ -194,14 +176,6 @@ static GQuark application_id;
 void
 prepare_boardlist_ui_initialization(OchushaApplication *application)
 {
-#ifdef CATEGORY_INFO_LOCK
-  if (pthread_mutex_init(&category_info_lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-#endif
-
   if (pthread_mutex_init(&board_list_lock, NULL) != 0)
     {
       fprintf(stderr, "Couldn't init a mutex.\n");
@@ -220,12 +194,13 @@ open_threadlist_view_cb(GtkWidget *selector, OchushaBulletinBoard *board,
 			gboolean in_tab, gboolean with_browser,
 			PanedNotebook *paned_notebook)
 {
+  OchushaApplication *application = g_object_get_qdata(G_OBJECT(selector),
+						       application_id);
   if (!with_browser)
-    paned_notebook_open_item_view(paned_notebook, board, in_tab);
+    paned_notebook_open_item_view(paned_notebook, board, in_tab,
+				  application->select_tab_when_opened);
   else
     {
-      OchushaApplication *application
-	= g_object_get_qdata(G_OBJECT(selector), application_id);
       if (application != NULL)
 	ochusha_open_url(application,
 			 ochusha_bulletin_board_get_base_url(board),
@@ -422,7 +397,6 @@ trace_free(gpointer pointer)
 static BoardCategoryGUIInfo *
 ensure_board_category_info(OchushaBoardCategory *category)
 {
-#ifndef CATEGORY_INFO_LOCK
   BoardCategoryGUIInfo *info = g_object_get_qdata(G_OBJECT(category),
 						  category_gui_info_id);
   if (info == NULL)
@@ -431,21 +405,6 @@ ensure_board_category_info(OchushaBoardCategory *category)
       g_object_set_qdata_full(G_OBJECT(category), category_gui_info_id,
 			      info, (GDestroyNotify)TRACE_FREE);
     }
-#else
-  BoardCategoryGUIInfo *info;
-
-  CATEGORY_INFO_LOCK
-  {
-    info = g_object_get_qdata(G_OBJECT(category), category_gui_info_id);
-    if (info == NULL)
-      {
-	info = G_NEW0(BoardCategoryGUIInfo, 1);
-	g_object_set_qdata_full(G_OBJECT(category), category_gui_info_id,
-				info, (GDestroyNotify)TRACE_FREE);
-      }
-  }
-  CATEGORY_INFO_UNLOCK;
-#endif
 
   return info;
 }
@@ -501,7 +460,7 @@ finalize_boardlist(OchushaApplication *application)
 }
 
 
-void
+static void
 make_new_thread(OchushaApplication *application)
 {
   PanedNotebook *contents_window;
