@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.17 2003/12/29 05:21:09 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.18 2003/12/30 17:21:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -228,7 +228,7 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 	NULL,
 	NULL,
 	0,
-	"<Separator>"
+	(char *)"<Separator>"
       },
       {
 	_("/Toggle Hide(_D)"),			/* menu path */
@@ -249,7 +249,7 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 	NULL,
 	NULL,
 	0,
-	"<Separator>"
+	(char *)"<Separator>"
       },
       {
 	_("/Copy Board's URL"),			/* menu path */
