@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.86 2003/12/29 18:46:34 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.89 2003/12/30 20:48:12 fuyu Exp $
  */
 
 #include "config.h"
@@ -95,7 +95,7 @@ static void thread_mouse_over_cb(ThreadlistView *view,
 static void thread_mouse_out_cb(ThreadlistView *view, OchushaBBSThread *thread,
 				OchushaApplication *application);
 static gboolean thread_title_popup_timeout(gpointer data);
-static void thread_title_popup_show();
+static void thread_title_popup_show(void);
 static gboolean thread_title_popup_paint_window(GtkWidget *widget);
 
 static void item_view_required_cb(PanedNotebook *paned_notebook,
@@ -138,23 +138,6 @@ static GtkWidget *create_write_dialog(OchushaApplication *application,
 static pthread_mutex_t thread_list_lock;
 static pthread_cond_t thread_list_condition;
 
-#if 0
-static pthread_mutex_t board_info_lock;
-#define BOARD_INFO_LOCK					\
-  if (pthread_mutex_lock(&board_info_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't lock a mutex.\n");	\
-      abort();						\
-    }
-
-#define BOARD_INFO_UNLOCK				\
-  if (pthread_mutex_unlock(&board_info_lock) != 0)	\
-    {							\
-      fprintf(stderr, "Couldn't unlock a mutex.\n");	\
-      abort();						\
-    }
-#endif
-
 #define THREAD_LIST_LOCK				\
   if (pthread_mutex_lock(&thread_list_lock) != 0)	\
     {							\
@@ -214,14 +197,6 @@ static const char *default_init_scm =
 void
 prepare_board_ui_initialization(OchushaApplication *application)
 {
-#ifdef BOARD_INFO_LOCK
- if (pthread_mutex_init(&board_info_lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-#endif
-
  if (pthread_mutex_init(&thread_list_lock, NULL) != 0)
     {
       fprintf(stderr, "Couldn't init a mutex.\n");
@@ -542,7 +517,6 @@ BulletinBoardGUIInfo *
 ensure_bulletin_board_info(OchushaBulletinBoard *board,
 			   OchushaApplication *application)
 {
-#ifndef BOARD_INFO_LOCK
   BulletinBoardGUIInfo *info = g_object_get_qdata(G_OBJECT(board),
 						  board_info_id);
   if (info == NULL)
@@ -557,27 +531,6 @@ ensure_bulletin_board_info(OchushaBulletinBoard *board,
 		       application);
       info->recover_mode = application->recover_mode;
     }
-#else
-  BulletinBoardGUIInfo *info;
-
-  BOARD_INFO_LOCK 
-  {
-    info = g_object_get_qdata(G_OBJECT(board), board_info_id);
-    if (info == NULL)
-      {
-	info = G_NEW0(BulletinBoardGUIInfo, 1);
-	g_object_set_qdata_full(G_OBJECT(board), board_info_id, info,
-				(GDestroyNotify)bulletin_board_gui_info_free);
-	g_signal_connect(G_OBJECT(board), "threadlist_read_thread_element",
-			 G_CALLBACK(threadlist_read_thread_element_cb), NULL);
-	g_signal_connect(G_OBJECT(board), "threadlist_write_thread_element",
-			 G_CALLBACK(threadlist_write_thread_element_cb),
-			 application);
-	info->recover_mode = application->recover_mode;
-      }
-  }
-  BOARD_INFO_UNLOCK;
-#endif
 
   return info;
 }
@@ -745,12 +698,13 @@ open_thread_view_cb(GtkWidget *selector, OchushaBBSThread *thread,
 		    gboolean in_tab, gboolean with_browser,
 		    PanedNotebook *paned_notebook)
 {
+  OchushaApplication *application = g_object_get_qdata(G_OBJECT(selector),
+						       application_id);
   if (!with_browser)
-    paned_notebook_open_item_view(paned_notebook, thread, in_tab);
+    paned_notebook_open_item_view(paned_notebook, thread, in_tab,
+				  application->select_tab_when_opened);
   else
     {
-      OchushaApplication *application
-	= g_object_get_qdata(G_OBJECT(selector), application_id);
       if (application != NULL)
 	ochusha_open_url(application,
 			 ochusha_bbs_thread_get_url_to_post_response(thread),
@@ -983,7 +937,8 @@ ochusha_open_thread(OchushaApplication *application,
     return;
 
   paned_notebook_open_item_view(PANED_NOTEBOOK(application->contents_window),
-				board, in_tab);
+				board, in_tab,
+				application->select_tab_when_opened);
   /*
    * Ĥ򳫤Τ̥åɤǹԤǽꡢ
    * Ǥϡ򳫤ΤϤθˤʤΤǡĤΤλ
@@ -1049,7 +1004,8 @@ open_thread_view(WorkerThread *employee, gpointer job_args)
 	specify_thread_view_point(thread, board_view, args->res_num);
 
 	if (board_view != NULL)
-	  paned_notebook_open_item_view(board_view, thread, args->in_tab);
+	  paned_notebook_open_item_view(board_view, thread, args->in_tab,
+					application->select_tab_when_opened);
 
 	OCHU_THREADS_LEAVE();
       }
@@ -1234,7 +1190,8 @@ ochusha_open_kako_thread(OchushaApplication *application,
     return;
 
   paned_notebook_open_item_view(PANED_NOTEBOOK(application->contents_window),
-				board, in_tab);
+				board, in_tab,
+				application->select_tab_when_opened);
   /*
    * Ĥ򳫤Τ̥åɤǹԤǽꡢ
    * Ǥϡ򳫤ΤϤθˤʤΤǡĤΤλ
@@ -1297,7 +1254,8 @@ open_kako_thread_view(WorkerThread *employee, gpointer job_args)
 	board_view = (PanedNotebook *)paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), board);
 
 	if (board_view != NULL)
-	  paned_notebook_open_item_view(board_view, thread, args->in_tab);
+	  paned_notebook_open_item_view(board_view, thread, args->in_tab,
+					application->select_tab_when_opened);
 
 	OCHU_THREADS_LEAVE();
       }
@@ -1639,7 +1597,7 @@ advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		PanedNotebook *paned_notebook)
 {
   if (paned_notebook_get_current_item(paned_notebook) != thread)
-    paned_notebook_open_item_view(paned_notebook, thread, FALSE);
+    paned_notebook_open_item_view(paned_notebook, thread, FALSE, TRUE);
   else
     {
       /* ڡ򥹥뤵 */
@@ -1656,7 +1614,7 @@ back_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 	     PanedNotebook *paned_notebook)
 {
   if (paned_notebook_get_current_item(paned_notebook) != thread)
-    paned_notebook_open_item_view(paned_notebook, thread, FALSE);
+    paned_notebook_open_item_view(paned_notebook, thread, FALSE, TRUE);
   else
     {
       /* ڡ򥹥뤵 */
@@ -1821,7 +1779,7 @@ thread_title_popup_timeout(gpointer data)
 
 
 static void
-thread_title_popup_show()
+thread_title_popup_show(void)
 {
   gchar buffer[1024];
 
@@ -2341,10 +2299,16 @@ write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
     {
       WorkerJob *job = G_NEW0(WorkerJob, 1);
       WriteResponseJobArgs *job_args = G_NEW0(WriteResponseJobArgs, 1);
+      GtkToggleButton *sage_button = g_object_get_data(G_OBJECT(write_dialog),
+						       "sage");
       
       job_args->thread = thread;
       job_args->name = G_STRDUP(name);
-      job_args->mailto = G_STRDUP(mailto);
+      if (strstr(mailto, "sage") == NULL
+	  && gtk_toggle_button_get_active(sage_button))
+	job_args->mailto = g_strdup_printf("%ssage", mailto);
+      else
+	job_args->mailto = G_STRDUP(mailto);
       job_args->message = message;
       job_args->dialog = write_dialog;
       job_args->application = application;
@@ -2695,6 +2659,7 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
 {
   GtkWidget *write_dialog;
   GtkWidget *dialog_vbox;
+  GtkWidget *sage_button;
   GtkWidget *url_hbox;
   GtkWidget *url_entry;
   GtkWidget *title_hbox;
@@ -2751,6 +2716,10 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
   editor = response_editor_new();
   response_editor = RESPONSE_EDITOR(editor);
 
+  /*  sage_button = gtk_toggle_button_new_with_label("sage"); */
+  sage_button = gtk_check_button_new_with_label("sage");
+  gtk_box_pack_start(response_editor->hbox, sage_button, FALSE, FALSE, 0);
+
   if (thread_info->last_name != NULL)
     {
       response_editor_add_name(response_editor, thread_info->last_name);
@@ -2805,6 +2774,7 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
 
   g_object_set_data(G_OBJECT(write_dialog), "editor", editor);
   g_object_set_data(G_OBJECT(write_dialog), "thread", thread);
+  g_object_set_data(G_OBJECT(write_dialog), "sage", sage_button);
 
   return write_dialog;
 }
