@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.57 2003/12/29 05:21:09 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.59 2003/12/30 20:48:12 fuyu Exp $
  */
 
 #include "config.h"
@@ -218,7 +218,7 @@ ochusha_init_application(OchushaApplication *application)
       NULL,			/* accelerator */
       NULL,			/* callback_func */
       0,			/* act */
-      "<Branch>"		/* type */
+      (char *)"<Branch>"	/* type */
     },
     {
       _("/File/_Open"),
@@ -232,11 +232,11 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       NULL,
       0,
-      "<Separator>"
+      (char *)"<Separator>"
     },
     {
       _("/File/_Quit"),
-      "<control>Q",
+      (char *)"<control>Q",
       on_quit,
       MAIN_MENU_QUIT,
       NULL
@@ -246,7 +246,7 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       NULL,
       0,
-      "<Branch>"
+      (char *)"<Branch>"
     },
     {
       _("/Board/_Refresh"),
@@ -260,18 +260,18 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       main_menu_callback,
       MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS,
-      "<CheckItem>",
+      (char *)"<CheckItem>",
     },
     {
       _("/_Thread"),
       NULL,
       NULL,
       0,
-      "<Branch>"
+      (char *)"<Branch>"
     },
     {
       _("/Thread/_Refresh"),
-      "F5",
+      (char *)"F5",
       main_menu_callback,
       MAIN_MENU_REFRESH_THREAD,
       NULL
@@ -288,7 +288,7 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       NULL,
       0,
-      "<Separator>"
+      (char *)"<Separator>"
     },
     {
       _("/Thread/Refresh _Threadlist"),
@@ -309,14 +309,14 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       main_menu_callback,
       MAIN_MENU_HIDE_HIDDEN_THREADS,
-      "<CheckItem>",
+      (char *)"<CheckItem>",
     },
     {
       _("/Tools"),
       NULL,
       NULL,
       0,
-      "<Branch>"
+      (char *)"<Branch>"
     },
 #if ENABLE_DEBUG_CONSOLE
     {
@@ -331,7 +331,7 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       NULL,
       0,
-      "<Separator>"
+      (char *)"<Separator>"
     },
 #endif
     {
@@ -346,7 +346,7 @@ ochusha_init_application(OchushaApplication *application)
       NULL,
       NULL,
       0,
-      "<Branch>"
+      (char *)"<Branch>"
     },
     {
       _("/Help/_About"),
@@ -630,18 +630,13 @@ ochusha_open_url(OchushaApplication *application, const gchar *url,
 	{
 	  /* ɽ */
 	  if (is_kako_html)
-	    {
-	      ochusha_open_kako_thread(application, board, url, in_tab);
-	    }
+	    ochusha_open_kako_thread(application, board, url, in_tab);
 	  else if (thread_id != NULL)
-	    {
-	      ochusha_open_thread(application, board, thread_id, from, in_tab);
-	    }
+	    ochusha_open_thread(application, board, thread_id, from, in_tab);
 	  else
-	    {
-	      paned_notebook_open_item_view(PANED_NOTEBOOK(application->contents_window),
-					    board, in_tab);
-	    }
+	    paned_notebook_open_item_view(PANED_NOTEBOOK(application->contents_window),
+					  board, in_tab,
+					  application->select_tab_when_opened);
 
 	  if (board_url != NULL)
 	    G_FREE(board_url);
@@ -791,7 +786,10 @@ add_stock_icon(GtkIconFactory *factory, const char *stock_id,
 
 static const GtkStockItem ochusha_stock_items[] =
 {
-  { OCHUSHA_STOCK_WRITE_RESPONSE, N_("_Write"), 0, 0, PACKAGE_NAME }
+  { (char *)OCHUSHA_STOCK_WRITE_RESPONSE,
+    (char *)N_("_Write"),
+    0, 0,
+    (char *)PACKAGE_NAME }
 };
 
 
@@ -1133,6 +1131,7 @@ write_optional_prefs(gzFile *file, gpointer user_data)
     }
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, default_open_in_tab);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, select_tab_when_opened);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, show_mailto_mode);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, a_bone_by_name);
@@ -1237,6 +1236,7 @@ configure_application(OchushaApplication *application)
       application->bookmark_text = G_STRDUP(_("==== My bookmark: I have read above. ===="));
 
       application->default_open_in_tab = FALSE;
+      application->select_tab_when_opened = FALSE;
       application->show_mailto_mode = OCHUSHA_DEFAULT_SHOW_MAILTO_MODE;
       application->a_bone_by_name = FALSE;
       application->a_bone_by_name_pattern = G_STRDUP("");
@@ -1408,6 +1408,9 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
   application->default_open_in_tab
     = ochusha_utils_get_attribute_boolean(pref_attrs, "default_open_in_tab");
 
+  application->select_tab_when_opened
+    = ochusha_utils_get_attribute_boolean(pref_attrs,
+					  "select_tab_when_opened");
   application->thread_view_font_name
     = ochusha_utils_get_attribute_string(pref_attrs, "thread_view_font_name");
 
@@ -2024,6 +2027,12 @@ preference_dialog_response_cb(GtkWidget *widget, gint response_id,
 	      }
 	  }
 
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "select_tab_when_opened");
+	if (tmp_data != NULL)
+	  application->select_tab_when_opened
+	    = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+
 	tmp_data = g_object_get_data(G_OBJECT(widget), "stick_bookmark");
 	if (tmp_data != NULL)
 	  {
@@ -2121,7 +2130,14 @@ build_ochusha_setting_frame(OchushaApplication *application,
   gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
   g_object_set_data(G_OBJECT(dialog), "default_open_in_tab", tmp_widget);
 
-  tmp_widget = gtk_check_button_new_with_label(_("Expand only one category at once."));
+  tmp_widget = gtk_check_button_new_with_label(_("Select the Tab When a New Tab is Opened."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->select_tab_when_opened);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "select_tab_when_opened", tmp_widget);
+
+  tmp_widget = gtk_check_button_new_with_label(_("Expand Only One Category at Once."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->expand_only_one_category);
   gtk_widget_show(tmp_widget);
@@ -2141,7 +2157,7 @@ build_ochusha_setting_frame(OchushaApplication *application,
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->board_tab_always_show);
   gtk_widget_show(tmp_widget);
-  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
   g_object_set_data(G_OBJECT(dialog), "board_tab_always_show", tmp_widget);
 
 #if 0
@@ -2150,7 +2166,7 @@ build_ochusha_setting_frame(OchushaApplication *application,
 			       application->boardlist_pane_style
 			       == VPANED_STYLE);
   gtk_widget_show(tmp_widget);
-  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
   g_object_set_data(G_OBJECT(dialog), "boardlist_pane_style",
 		    tmp_widget);
 #endif
@@ -2424,7 +2440,8 @@ build_thread_view_setting_frame(OchushaApplication *application,
   gtk_box_pack_start(GTK_BOX(outer_vbox), hbox, FALSE, FALSE, 0);
 
 
-  tmp_widget = gtk_check_button_new_with_label(_("Enable transparent a bone."));
+  tmp_widget
+    = gtk_check_button_new_with_label(_("Enable Transparent a Bone."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->enable_transparent_a_bone);
   gtk_widget_show(tmp_widget);
@@ -2432,7 +2449,7 @@ build_thread_view_setting_frame(OchushaApplication *application,
   g_object_set_data(G_OBJECT(dialog), "enable_transparent_a_bone",
 		    tmp_widget);
 
-  tmp_widget = gtk_check_button_new_with_label(_("Disable popup of response made a bone."));
+  tmp_widget = gtk_check_button_new_with_label(_("Disable Popup of Response Made a Bone."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->disable_popup_a_bone);
   gtk_widget_show(tmp_widget);
@@ -2449,7 +2466,7 @@ build_thread_view_setting_frame(OchushaApplication *application,
   gtk_widget_show(vbox);
   gtk_container_add(GTK_CONTAINER(thread_frame), vbox);
 
-  tmp_widget = gtk_check_button_new_with_label(_("Show mailto literally."));
+  tmp_widget = gtk_check_button_new_with_label(_("Show `mailto' Field Literally."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->show_mailto_mode
 			       == THREAD_VIEW_MAILTO_MODE_SHOW);
@@ -2459,7 +2476,7 @@ build_thread_view_setting_frame(OchushaApplication *application,
 		    tmp_widget);
 
 
-  tmp_widget = gtk_check_button_new_with_label(_("A bone by name field."));
+  tmp_widget = gtk_check_button_new_with_label(_("A Bone by Name Field."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->a_bone_by_name);
   gtk_widget_show(tmp_widget);
@@ -2472,7 +2489,7 @@ build_thread_view_setting_frame(OchushaApplication *application,
   g_object_set_data(G_OBJECT(dialog), "a_bone_by_name_pattern", tmp_widget);
 
 
-  tmp_widget = gtk_check_button_new_with_label(_("A bone by ID."));
+  tmp_widget = gtk_check_button_new_with_label(_("A Bone by ID."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->a_bone_by_id);
   gtk_widget_show(tmp_widget);
@@ -2485,7 +2502,7 @@ build_thread_view_setting_frame(OchushaApplication *application,
   g_object_set_data(G_OBJECT(dialog), "a_bone_by_id_pattern", tmp_widget);
 
 
-  tmp_widget = gtk_check_button_new_with_label(_("A bone by content."));
+  tmp_widget = gtk_check_button_new_with_label(_("A Bone by Content."));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
 			       application->a_bone_by_content);
   gtk_widget_show(tmp_widget);
@@ -2522,14 +2539,14 @@ build_bookmark_setting_frame(OchushaApplication *application,
   gtk_container_add(GTK_CONTAINER(outer_frame), outer_vbox);
 
 
-  tmp_widget = gtk_radio_button_new_with_label(NULL, _("Do NOT move bookmark automatically."));
+  tmp_widget = gtk_radio_button_new_with_label(NULL, _("Do NOT Move Bookmarks Automatically."));
   gtk_widget_show(tmp_widget);
   gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
   g_object_set_data(G_OBJECT(dialog), "stick_bookmark", tmp_widget);
 
   tmp_widget
     = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(tmp_widget),
-						  _("Move bookmark to lead unread responses before loading and refreshment of thread."));
+						  _("Move Bookmarks to Lead Unread Responses before Loading and Refreshment of Threads."));
   gtk_widget_show(tmp_widget);
   gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
 
