@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.11 2003/12/29 08:47:44 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.13 2003/12/30 20:48:12 fuyu Exp $
  */
 
 #include "config.h"
@@ -87,8 +87,6 @@ static void menu_changed_cb(GtkOptionMenu *option_menu,
 			    PanedNotebook *paned_notebook);
 static void menu_item_activate_cb(GtkMenuItem *menu_item,
 				  PanedNotebook *paned_notebook);
-static void foreach_item(gpointer data, gpointer user_data);
-static void foreach_item_view(gpointer data, gpointer user_data);
 static void close_item_view_button_cb(gpointer unused,
 				      PanedNotebook *paned_notebook);
 static void go_forward_button_cb(gpointer unused,
@@ -132,8 +130,8 @@ paned_style_get_type(void)
     {
       static const GEnumValue values[] =
 	{
-	  { HPANED_STYLE, "HPANED_STYLE", "hpaned" },
-	  { VPANED_STYLE, "VPANED_STYLE", "vpaned" },
+	  { HPANED_STYLE, (char *)"HPANED_STYLE", (char *)"hpaned" },
+	  { VPANED_STYLE, (char *)"VPANED_STYLE", (char *)"vpaned" },
 	  { 0, NULL, NULL }
 	};
 
@@ -1111,17 +1109,19 @@ paned_notebook_foreach_item_view(PanedNotebook *paned_notebook, GFunc func,
  * itemNotebookɽ롣
  *
  * itemɽǤ(ModNotebook˴ޤޤƤ)硢in_tabǤС
- * itemɽƤڡ򤷡Ǥв⤷ʤ롣
+ * itemɽƤڡ򤹤롣in_tabξ硢select_page
+ * ǤХ֤򤷡ξˤϲ⤷ʤ롣
  *
  * itemɽǤʤ硢item_view_requiredʥȯԤ
  * ηitemɽ륦åȤͿ줿ˤϤΥ
  * ȤModNotebookɲä롣λin_tabξˤϸ򤵤Ƥ
  * ڡɽƤitemĤǤΰ֤˥åȤ
- * Υڡ򤹤롣in_tabξˤñɲä롣
+ * Υڡ򤹤롣in_tabġselect_page⿿ǤХ֤
+ * 롣
  */
 void
 paned_notebook_open_item_view(PanedNotebook *paned_notebook, gpointer item,
-			      gboolean in_tab)
+			      gboolean in_tab, gboolean select_page)
 {
   ItemViewRelation *relation = find_item_view_relation(paned_notebook, item);
   GtkWidget *item_view = relation != NULL ? relation->item_view : NULL;
@@ -1132,7 +1132,7 @@ paned_notebook_open_item_view(PanedNotebook *paned_notebook, gpointer item,
 
   if (item_view != NULL)
     {
-      if (in_tab)
+      if (in_tab && !select_page)
 	return;
 
       page = mod_notebook_page_num(paned_notebook->item_contents, item_view);
@@ -1198,6 +1198,14 @@ paned_notebook_open_item_view(PanedNotebook *paned_notebook, gpointer item,
 	  mod_notebook_set_show_tabs(paned_notebook->item_contents, TRUE);
 	  gtk_widget_queue_resize(GTK_WIDGET(paned_notebook));
 	}
+
+      if (paned_notebook->number_of_items_shown > 1 && select_page)
+	{
+	  page = mod_notebook_page_num(paned_notebook->item_contents,
+				       item_view);
+	  mod_notebook_set_current_page(paned_notebook->item_contents, page);
+	}
+
       return;
     }
 
