@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: regex_utils.c,v 1.2 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: regex_utils.c,v 1.3 2003/12/30 15:51:01 fuyu Exp $
  */
 
 #include "config.h"
@@ -183,7 +183,12 @@ regex_editor_synthesize_regular_expression(const gchar *text)
       if (tmp_pos == end_pos)
 	goto next_line;
 
-      if (regex_new(&regex, tmp_pos, end_pos, REG_OPTION_EXTEND, REGCODE_UTF8,
+      if (regex_new(&regex, tmp_pos, end_pos, REG_OPTION_EXTEND,
+#ifdef REG_ENCODING_UTF8
+		    REG_ENCODING_UTF8,
+#else /* old style */
+		    REGCODE_UTF8,
+#endif
 		    REG_SYNTAX_POSIX_EXTENDED, NULL) == REG_NORMAL)
 	{
 	  gchar *sub_exp = G_STRNDUP(tmp_pos, end_pos - tmp_pos + 1);
@@ -310,6 +315,21 @@ oniguruma_regex_new(const gchar *pattern, const char *encoding)
 
   if (encoding != NULL)
     {
+#ifdef REG_ENCODING_UNDEF
+      if (strcmp(encoding, "CP932") == 0)
+	code = REG_ENCODING_SJIS;
+      else if (strcmp(encoding, "EUC-JP") == 0)
+	code = REG_ENCODING_EUC_JP;
+      else if (strcmp(encoding, "UTF-8") == 0)
+	code = REG_ENCODING_UTF8;
+      else if (strcmp(encoding, "Shift_JIS") == 0)
+	code = REG_ENCODING_SJIS;
+      else
+	code = REG_ENCODING_UTF8;
+    }
+  else
+    code = REG_ENCODING_UTF8;
+#else /* old style */
       if (strcmp(encoding, "CP932") == 0)
 	code = REGCODE_SJIS;
       else if (strcmp(encoding, "EUC-JP") == 0)
@@ -323,6 +343,7 @@ oniguruma_regex_new(const gchar *pattern, const char *encoding)
     }
   else
     code = REGCODE_UTF8;
+#endif
 
   if (regex_new(&result, (UChar *)pattern, (UChar *)pattern + strlen(pattern),
 		REG_OPTION_EXTEND, code,
