@@ -23,14 +23,13 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: response_editor.h,v 1.3 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: response_editor.h,v 1.4 2003/11/23 21:15:48 fuyu Exp $
  */
 
 #ifndef _RESPONSE_EDITOR_H_
 #define _RESPONSE_EDITOR_H_
 
 #include "ochusha.h"
-#include "ochusha_bbs_thread.h"
 
 #include <gtk/gtk.h>
 
@@ -65,8 +64,6 @@ struct _ResponseEditor
 
   GList *name_list;
   GList *mail_list;
-
-  OchushaBBSThread *thread;
 };
 
 
@@ -78,7 +75,7 @@ struct _ResponseEditorClass
 
 GType response_editor_get_type(void);
 
-GtkWidget *response_editor_new(OchushaBBSThread *thread);
+GtkWidget *response_editor_new(void);
 
 const gchar *response_editor_get_name(ResponseEditor *editor);
 void response_editor_set_name(ResponseEditor *editor, const gchar *name);
