@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.c,v 1.36 2003/12/29 05:21:09 fuyu Exp $
+ * $Id: threadlist_view.c,v 1.37 2003/12/30 17:21:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -327,7 +327,7 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 	NULL,
 	NULL,
 	0,
-	"<Separator>"
+	(char *)"<Separator>"
       },
       {
 	_("/Mark(_*)"),				/* menu path */
@@ -355,7 +355,7 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 	NULL,
 	NULL,
 	0,
-	"<Separator>"
+	(char *)"<Separator>"
       },
       {
 	_("/Reset(_R)"),			/* menu path */
@@ -369,7 +369,7 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 	NULL,
 	NULL,
 	0,
-	"<Separator>"
+	(char *)"<Separator>"
       },
       {
 	_("/Copy Thread's URL"),		/* menu path */
