@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.18 2003/12/20 04:20:18 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.19 2003/12/30 17:21:46 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -194,16 +194,10 @@ typedef struct _ThreadlistEntryVisualParameter
 GType threadlist_view_get_type(void);
 GtkWidget *threadlist_view_new(void);
 
-const char *threadlist_view_get_foreground(ThreadlistView *view,
-					   ThreadlistEntryForeground code);
-void threadlist_view_set_foreground(ThreadlistView *view,
-				    ThreadlistEntryForeground code,
-				    const char *color);
-const char *threadlist_view_get_background(ThreadlistView *view,
-					   ThreadlistEntryBackground code);
-void threadlist_view_set_background(ThreadlistView *view,
-				    ThreadlistEntryBackground code,
-				    const char *color);
+void threadlist_entry_set_foreground_color(ThreadlistEntryForeground color,
+					   const char *color_name);
+void threadlist_entry_set_background_color(ThreadlistEntryBackground color,
+					   const char *color_name);
 
 gboolean threadlist_view_get_default_open_in_tab(ThreadlistView *view);
 void threadlist_view_set_default_open_in_tab(ThreadlistView *view,
