@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.h,v 1.7 2003/12/04 07:30:42 fuyu Exp $
+ * $Id: ochusha_async_buffer.h,v 1.8 2003/12/19 03:11:47 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_ASYNCBUF_H_
@@ -97,11 +97,11 @@ GType ochusha_async_buffer_get_type(void);
 
 OchushaAsyncBuffer *ochusha_async_buffer_new(char *buffer, int length,
 					     DestructFunc *destructor);
+OchushaAsyncBuffer *ochusha_async_buffer_new_with_file(int fd);
+OchushaAsyncBuffer *ochusha_async_buffer_new_with_file_mmap(int fd);
 
-gboolean ochusha_async_buffer_active_ref(OchushaAsyncBuffer *buffer,
-					 const char *user);
-void ochusha_async_buffer_active_unref(OchushaAsyncBuffer *buffer,
-				       const char *user);
+gboolean ochusha_async_buffer_active_ref(OchushaAsyncBuffer *buffer);
+void ochusha_async_buffer_active_unref(OchushaAsyncBuffer *buffer);
 
 void ochusha_async_buffer_suspend_all(void);
 void ochusha_async_buffer_resume_all(void);
@@ -111,34 +111,26 @@ void ochusha_async_buffer_resume(OchushaAsyncBuffer *buffer);
 void ochusha_async_buffer_terminate(OchushaAsyncBuffer *buffer);
 
 
-gboolean ochusha_async_buffer_fix(OchushaAsyncBuffer *buffer,
-				  const char *user);
+gboolean ochusha_async_buffer_fix(OchushaAsyncBuffer *buffer);
 gboolean ochusha_async_buffer_update_length(OchushaAsyncBuffer *buffer,
-					    int length,
-					    const char *user);
-gboolean ochusha_async_buffer_resize(OchushaAsyncBuffer *buffer, int length,
-				     const char *user);
+					    int length);
+gboolean ochusha_async_buffer_resize(OchushaAsyncBuffer *buffer, int length);
 gboolean ochusha_async_buffer_ensure_free_space(OchushaAsyncBuffer *buffer,
-						int length,
-						const char *user);
+						int length);
 
 gboolean ochusha_async_buffer_append_data(OchushaAsyncBuffer *buffer,
-					  const char *data,
-					  int length, const char *user);
+					  const char *data, int length);
+
+gboolean ochusha_async_buffer_read_file(OchushaAsyncBuffer *buffer, int fd);
 
 void ochusha_async_buffer_lock(OchushaAsyncBuffer *buffer);
 void ochusha_async_buffer_unlock(OchushaAsyncBuffer *buffer);
 
-gboolean ochusha_async_buffer_check_active(OchushaAsyncBuffer *buffer,
-					   const char *user);
-gboolean ochusha_async_buffer_signal(OchushaAsyncBuffer *buffer,
-				     const char *user);
-gboolean ochusha_async_buffer_broadcast(OchushaAsyncBuffer *buffer,
-					const char *user);
-gboolean ochusha_async_buffer_wait(OchushaAsyncBuffer *buffer,
-				   const char *user);
-gboolean ochusha_async_buffer_is_busy(OchushaAsyncBuffer *buffer,
-				      const char *user);
+gboolean ochusha_async_buffer_check_active(OchushaAsyncBuffer *buffer);
+gboolean ochusha_async_buffer_signal(OchushaAsyncBuffer *buffer);
+gboolean ochusha_async_buffer_broadcast(OchushaAsyncBuffer *buffer);
+gboolean ochusha_async_buffer_wait(OchushaAsyncBuffer *buffer);
+gboolean ochusha_async_buffer_is_busy(OchushaAsyncBuffer *buffer);
 
 void ochusha_async_buffer_free_when_finished(OchushaAsyncBuffer *buffer);
 
