@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.13 2003/12/24 03:40:50 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.14 2003/12/30 19:58:19 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -90,7 +90,7 @@ struct _OchushaBulletinBoard
   GHashTable *thread_table;	/* ID(DATե̾)=>(OchushaBBSThread *) */
   GSList *dropped_list;		/* DAT(OchushaBBSThread *)ꥹ */
 
-  OchushaBBSType bbs_type;	/* ǼĤμࡽ2chΤߤ */
+  OchushaBBSType bbs_type;	/* ǼĤμ */
 
   gboolean hidden;		/* İ鱣 */
   gboolean killed;		/* İ¸˼ΤƤ */
