@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.19 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.21 2003/12/30 17:22:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -939,14 +939,14 @@ typedef struct _HTML2DATConverterJobArgs
 } HTML2DATConverterJobArgs;
 
 
-static char *title_pattern_string = NULL;
-static char *title_pattern_end = NULL;
-static char *jbbs_shitaraba_response_pattern_string = NULL;
-static char *jbbs_shitaraba_response_pattern_end = NULL;
-static char *machibbs_response_pattern_string = NULL;
-static char *machibbs_response_pattern_end = NULL;
-static char *mitinoku_response_pattern_string = NULL;
-static char *mitinoku_response_pattern_end = NULL;
+static const char *title_pattern_string = NULL;
+static const char *title_pattern_end = NULL;
+static const char *jbbs_shitaraba_response_pattern_string = NULL;
+static const char *jbbs_shitaraba_response_pattern_end = NULL;
+static const char *machibbs_response_pattern_string = NULL;
+static const char *machibbs_response_pattern_end = NULL;
+static const char *mitinoku_response_pattern_string = NULL;
+static const char *mitinoku_response_pattern_end = NULL;
 
 
 static void
@@ -1016,16 +1016,26 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
-      if (regex_new(&title_pattern, title_pattern_string, title_pattern_end,
+      if (regex_new(&title_pattern,
+		    (char *)title_pattern_string, (char *)title_pattern_end,
+#ifdef REG_ENCODING_EUC_JP
+		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
+#else /* old style */
 		    REG_OPTION_EXTEND, REGCODE_EUCJP,
+#endif
 		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
 	}
-      if (regex_new(&response_pattern, jbbs_shitaraba_response_pattern_string,
-		    jbbs_shitaraba_response_pattern_end,
+      if (regex_new(&response_pattern,
+		    (char *)jbbs_shitaraba_response_pattern_string,
+		    (char *)jbbs_shitaraba_response_pattern_end,
+#ifdef REG_ENCODING_EUC_JP
+		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
+#else /* old style */
 		    REG_OPTION_EXTEND, REGCODE_EUCJP,
+#endif
 		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
@@ -1039,17 +1049,27 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
       break;
 
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-      if (regex_new(&title_pattern, title_pattern_string, title_pattern_end,
+      if (regex_new(&title_pattern,
+		    (char *)title_pattern_string, (char *)title_pattern_end,
+#ifdef REG_ENCODING_SJIS
+		    REG_OPTION_EXTEND, REG_ENCODING_SJIS,
+#else /* old style */
 		    REG_OPTION_EXTEND, REGCODE_SJIS,
+#endif
 		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
 	}
-        if (regex_new(&response_pattern, machibbs_response_pattern_string,
-		      machibbs_response_pattern_end,
-		      REG_OPTION_EXTEND, REGCODE_SJIS,
-		      REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
+      if (regex_new(&response_pattern,
+		    (char *)machibbs_response_pattern_string,
+		    (char *)machibbs_response_pattern_end,
+#ifdef REG_ENCODING_SJIS
+		    REG_OPTION_EXTEND, REG_ENCODING_SJIS,
+#else /* old style */
+		    REG_OPTION_EXTEND, REGCODE_SJIS,
+#endif
+		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
@@ -1062,16 +1082,26 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
       break;
 
     case OCHUSHA_BBS_TYPE_MITINOKU:
-      if (regex_new(&title_pattern, title_pattern_string, title_pattern_end,
+      if (regex_new(&title_pattern,
+		    (char *)title_pattern_string, (char *)title_pattern_end,
+#ifdef REG_ENCODING_EUC_JP
+		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
+#else /* old style */
 		    REG_OPTION_EXTEND, REGCODE_EUCJP,
+#endif
 		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
 	}
-      if (regex_new(&response_pattern, mitinoku_response_pattern_string,
-		    mitinoku_response_pattern_end,
+      if (regex_new(&response_pattern,
+		    (char *)mitinoku_response_pattern_string,
+		    (char *)mitinoku_response_pattern_end,
+#ifdef REG_ENCODING_EUC_JP
+		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
+#else /* old style */
 		    REG_OPTION_EXTEND, REGCODE_EUCJP,
+#endif
 		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
