@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.h,v 1.6 2003/11/25 18:20:44 fuyu Exp $
+ * $Id: ochusha_utils_2ch.h,v 1.7 2003/12/19 03:13:38 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UTILS_2CH_H_
@@ -45,7 +45,8 @@ gboolean ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
 				     OchushaBBSType *bbs_type_p,
 				     char **board_id_p,
 				     char **thread_id_p,
-				     unsigned int *from_p, unsigned int *to_p);
+				     unsigned int *from_p, unsigned int *to_p,
+				     gboolean *is_kako_html_p);
 
 typedef gboolean EachCategoryCallback(OchushaBoardCategory *category,
 				      gpointer callback_data);
